<?php
/**
 * Questo file è parte del plugin WooCommerce v3.x di Fattura24
 * Autore: Fattura24.com <info@fattura24.com>
 *
 * di gestione degli scripts lato admin
 */

namespace fattura24;

if (!defined('ABSPATH')) {
    exit;
}

function fatt_24_admin_scripts()
{
    $scripts = array('f24_pdfcmd', 'f24_download'); // sempre disponibile
    $page = fatt_24_get_page();
    $path = '/js/';
    $data = [
        'download_pdf_file' => wp_create_nonce('download_pdf_file'),
        'url' => admin_url('admin-ajax.php')
    ];

    /**
     * Scripts utilizzati nella schermata 'impostazioni generali' di Fattura24
     */
    switch ($page) {
        case 'fatt-24-settings':
            $path .= 'settings/';
            $scripts = [
                        'f24_settings_options',
                        'f24_send_reviews',
                        'f24_test_key',
                        'f24_default_purpose',
                        'f24_api_message',
                        'f24_download_log'
                    ];
            $data = [
                        'apiKey' => get_option('fatt-24-API-key'),
                        'apiText' => fatt_24_getApiInputMessage(),
                        'source' => FATT_24_API_SOURCE,
                        'f24Info' => fatt_24_getInfo(),
                        'wp_debug' => WP_DEBUG,
                        'f24_debug' => get_option('fatt-24-log-enable'),
                        'plugin_path' => fatt_24_url('/'),
                        'rating_nonce' => wp_create_nonce('rating_nonce'),
                        'logFileName' => fatt_24_getLogFileName(),
                        'download_nonce' => wp_create_nonce('fatt_24_download_nonce'),
                        'url' => admin_url('admin-ajax.php')
                    ];
            break;
        default:
            break;    
    }

    foreach ($scripts as $script) {
        $file = $path . $script . '.js';
        wp_enqueue_script($script, plugins_url($file, __FILE__), array('jquery'));
        wp_localize_script($script, 'f24_scripts_data', $data);
    }
}

/**
 *  Aggiunge il link 'impostazioni' nella schermata di elenco plugin
 */
function fatt_24_settings_link($actions)
{
    $action_links = array(
        'settings' => '<a href="' . admin_url('options-general.php?page=fatt-24-settings') . '" aria-label="' . esc_attr__('View Fattura24 Settings', 'fattura24') . '">' . esc_html__('Settings', 'fattura24') . '</a>',
    );
    return array_merge($action_links, $actions);
}

/**
 *  Aggiunge links nella schermata di elenco plugin, a destra di 'Visualizza i dettagli'
 */
function fatt_24_row_meta($links, $file)
{
    $plugin_basename = plugin_basename(F24_PLUGIN_FILE);
    if ($plugin_basename !== $file) {
        return $links;
    }

    $row_meta = array(
        'docs' => '<a target="_blank" href="' . esc_url(apply_filters('fattura24_docs_url', 'https://www.fattura24.com/woocommerce-plugin-fatturazione/')) . '" aria-label="'. esc_attr__('View Fattura24 documentation', 'fattura24') . '">'. esc_html__('Fattura24 Docs', 'fattura24') . '</a>',
        'support' => '<a href="' . esc_url(apply_filters('fattura24_support_url', admin_url('options-general.php?page=fatt-24-support'))) . '" aria-label="'. esc_attr__('Support', 'fattura24') . '">'. esc_html__('Fattura24 Support', 'fattura24') . '</a>',
        'video_guides' => '<a target="_blank" href="' . esc_url(apply_filters('fattura24_video_guides', 'https://www.youtube.com/watch?v=svsJbyVNQmk&list=PLCvEiE9DaQULWoz7nUmiKihuMxWo4DxLb')) . '" aria-label="'. esc_attr__('View Fattura24 video guides', 'fattura24') . '">'. esc_html__('Video guides', 'fattura24') . '</a>',
        'review' => '<a target="_blank" href="' . esc_url(apply_filters('fattura24_review', 'https://wordpress.org/support/plugin/fattura24/reviews/?rate=5#new-post')) . '" aria-label="'. esc_attr__('Review Fattura24', 'fattura24') . '">'. esc_html__('Review', 'fattura24') . '</a>'
    );

    return array_merge($links, $row_meta);
}
